@@ -50,6 +50,8 @@ private:
 	static const char* VCF_SNP_TYPE;
 	static const char* VCF_INDEL_TYPE_01;
 	static const char* VCF_INDEL_TYPE_02;
+	static const char* VCF_ALT_ALLELE_DEL;
+	static const char* VCF_ALT_ALLELE_INS;
 
 	char* map_file;
 	Reader* map_reader;
